﻿using System;
using System.Windows.Input;

namespace Binding_12
{
    public class DelegateCommand : ICommand
    {
        public delegate void ExecuteDelegate(object parameter);
        public delegate bool CanExecuteDelegate(object parameter);

        private ExecuteDelegate execute;
        private CanExecuteDelegate canExecute;

        public DelegateCommand(ExecuteDelegate execute, CanExecuteDelegate canExecute = null)
        {
            this.execute = execute ?? throw new ArgumentNullException(nameof(execute));
            this.canExecute = canExecute;
        }

        public void Execute(object parameter)
        {
            execute(parameter);
        }

        public bool CanExecute(object parameter)
        {
            return canExecute?.Invoke(parameter) ?? true;
        }

        public event EventHandler CanExecuteChanged
        {
            add { CommandManager.RequerySuggested += value; }
            remove { CommandManager.RequerySuggested -= value; }
        }
    }
}
