﻿using Binding_12.Model;
using System.Net.NetworkInformation;
using System.Windows;
using System.Windows.Input;


namespace Binding_12.ViewModel
{
public class MainWindowViewModel : NotifyPropertyBase
{
    private string _fromValue;
    private string _toValue;
    private Currency _fromCurrency;
    private Currency _toCurrency;
    private string _status;

    public MainWindowViewModel()
    {
        // DelegateCommands
        RefreshCommand = new DelegateCommand(OnRefresh, OnCanRefresh);

        // CommandBindings (RoutedUICommands)
        CloseCommandBinding = new CommandBinding(ApplicationCommands.Close,
            OnClose,
            OnCanClose);

        // Währungen lesen
        OnRefresh(null);
    }

    public Currencies Currencies { get; set; }
    public string FromValue
    {
        get { return _fromValue; }
        set
        {
            bool isDecimal = decimal.TryParse(value, out decimal fromValue);
            fromValue = isDecimal ? fromValue : 0.0m;

            OnPropertyChanged(ref _fromValue, value);
            if(ToCurrency != null)
                ToValue = (ToCurrency.Rate * fromValue).ToString();
        }
    }
    public string ToValue
    {
        get { return _toValue; }
        set { OnPropertyChanged(ref _toValue, value); }
    }
    public Currency FromCurrency
    {
        get { return _fromCurrency; }
        set { OnPropertyChanged(ref _fromCurrency, value); }
    }
    public Currency ToCurrency
    {
        get { return _toCurrency; }
        set { OnPropertyChanged(ref _toCurrency, value); FromValue = _fromValue; }
    }
    public string Status
    {
        get { return _status; }
        set { OnPropertyChanged(ref _status, value); }
    }

    public DelegateCommand RefreshCommand { get; private set; }

    public CommandBinding CloseCommandBinding { get; private set; }

    private bool OnCanRefresh(object obj)
    {
        // Netzwerkverbindung prüfen
        return NetworkInterface.GetIsNetworkAvailable();
    }

    private void OnRefresh(object obj)
    {
        Currencies = Currencies.Load();
        FromCurrency = Currencies[0];
        ToCurrency = Currencies[1];
        FromValue = "1";
        Status = $"Währungen für den {Currencies.Date:d} geladen";
    }

    private void OnClose(object sender, ExecutedRoutedEventArgs e)
    {
        Application.Current.Shutdown();
    }

    private void OnCanClose(object sender, CanExecuteRoutedEventArgs e)
    {
        e.CanExecute = true;
    }
}
}
