﻿using System;
using System.Collections.ObjectModel;
using System.IO;
using System.Linq;
using System.Windows.Media.Imaging;

namespace ItemsControl_3
{
    public class Picture
    {
        public string Name { get; set; }
        public BitmapImage BitmapImage { get; set; }
        public DateTime DateCreated { get; set; }
        public string Path { get; set; }
        public string FileType { get; set; }
    }

    public class PictureList : ObservableCollection<Picture>
    {
        public PictureList()
        {
            Refresh();
        }

        private void Refresh()
        {
            string pathPictures = Environment.GetFolderPath(Environment.SpecialFolder.MyPictures);

            string[] fileNames = Directory.GetFiles(pathPictures, "*.png")
                                            .Union(Directory.GetFiles(pathPictures, "*.jpg"))
                                            .Union(Directory.GetFiles(pathPictures, "*.jpeg"))
                                            .OrderBy(f => f)
                                            .ToArray();

            foreach (string fileName in fileNames)
            {
                BitmapImage bitmap = new BitmapImage();

                bitmap.BeginInit();
                bitmap.UriSource = new Uri(fileName);
                bitmap.DecodePixelWidth = 100;
                bitmap.EndInit();

                this.Add(new Picture()
                {
                    Name = Path.GetFileNameWithoutExtension(fileName),
                    BitmapImage = bitmap,
                    DateCreated = File.GetCreationTime(fileName),
                    Path = fileName,
                    FileType = Path.GetExtension(fileName)
                });
            }
        }
    }
}
