﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace MiscControls_4
{
    /// <summary>
    /// Interaktionslogik für MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            fontList.ItemsSource = Fonts.SystemFontFamilies.OrderBy(f => f.Source);
            fontList.SelectedIndex = 0;
        }
        private void OnClose(object sender, RoutedEventArgs e)
        {
            MessageBoxResult result = MessageBox.Show(
                "Wirklich beenden?",
                "Zeichentabelle",
                MessageBoxButton.YesNo,
                MessageBoxImage.Question);

            if (result == MessageBoxResult.Yes)
                Close();
        }
        private async void OnFontChanged(object sender, SelectionChangedEventArgs e)
        {
            if (fontList.SelectedIndex == -1)
                return;
            await ShowFont((FontFamily)fontList.SelectedItem);
        }
        private async Task ShowFont(FontFamily fontFamily)
        {
            wrapPanel.Children.Clear();

            int from = int.Parse(fromUnicode.Text);
            int to = int.Parse(toUnicode.Text);

            progressBar.Minimum = from;
            progressBar.Maximum = to;

            await Task.Run(() =>
            {
                for (int i = from; i <= to; i++)
                {
                    this.Dispatcher.Invoke(() =>
                    {
                        foreach (Typeface typeface in fontFamily.GetTypefaces())
                        {
                            GlyphTypeface glyph;

                            if (typeface.TryGetGlyphTypeface(out glyph) &&
                                glyph.CharacterToGlyphMap.ContainsKey(i))
                            {
                                var button = new Button
                                {
                                    Content = (char)i,
                                    FontFamily = fontFamily,
                                    FontSize = fontSize.Value,
                                    Margin = new Thickness(1),
                                    Background = Brushes.Transparent,
                                    BorderBrush = Brushes.Transparent,
                                    ToolTip = $"Unicode: &#x{i:x4};\nDezimal: {i}"
                                };
                                wrapPanel.Children.Add(button);
                                break;
                            }
                        }
                        progressBar.Value++;
                    });
                }
            });
            progressBar.Value = 0;
            info.Text = $"Anzahl Zeichen: {wrapPanel.Children.Count}";
        }
        private void OnFontSizeChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            if (wrapPanel == null)
                return;
            foreach (Button button in wrapPanel.Children)
            {
                button.FontSize = e.NewValue;
            }
        }
        private async void OnRefreshCharacters(object sender, RoutedEventArgs e)
        {
            await ShowFont((FontFamily)fontList.SelectedItem);
        }
    }
}
