﻿using Microsoft.Win32;
using System;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Ink;
using System.Windows.Media;

namespace MiscControls_7_Painter
{
    /// <summary>
    /// Interaktionslogik für MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            PropertyInfo[] propertyInfosColor =
                typeof(Colors)
                .GetProperties()
                .OrderBy((pi) =>
                {
                    Color c = (Color)pi.GetValue(null, null);
                    return c.R + c.G + c.B; // von dunkel nach hell sortieren
                })
                .ToArray();
            colorList.ItemsSource = propertyInfosColor;
            colorList.SelectedIndex = 0;
        }

        private void OnNew(object sender, RoutedEventArgs e)
        {
            int count = sketchSheets.Items.Count;
            sketchSheets.Items.Add(
                new TabItem()
                {
                    Header = $"Blatt {count + 1}",
                    Content = new InkCanvas()
                });
            sketchSheets.SelectedIndex = count;
        }

        private void OnOpen(object sender, RoutedEventArgs e)
        {
            var dialog = new OpenFileDialog
            {
                Filter = "isf Dateien (*.isf)|*.isf"
            };

            if (dialog.ShowDialog() == true)
            {
                OnNew(null, null);
                TabItem tab = (TabItem)sketchSheets.SelectedItem;
                InkCanvas inkCanvas = (InkCanvas)tab.Content;

                using (var fileStream = new FileStream(dialog.FileName, FileMode.Open))
                {
                    inkCanvas.Strokes = new StrokeCollection(fileStream);
                }
                tab.Header = Path.GetFileNameWithoutExtension(dialog.FileName);
            }
        }

        private void OnSave(object sender, RoutedEventArgs e)
        {
            var dialog = new SaveFileDialog()
            {
                Filter = "isf Dateien (*.isf)|*.isf"
            };

            if (dialog.ShowDialog() == true)
            {
                TabItem tab = (TabItem)sketchSheets.SelectedItem;
                InkCanvas inkCanvas = (InkCanvas)tab.Content;

                using (var fileStream = new FileStream(dialog.FileName, FileMode.Create))
                {
                    inkCanvas.Strokes.Save(fileStream, true);
                }
                tab.Header = Path.GetFileNameWithoutExtension(dialog.FileName);
                status.Text = $"{dialog.FileName} gespeichert";
            }
        }

        private void OnClose(object sender, RoutedEventArgs e)
        {
            Close();
        }

        private void OnEditingModeChanged(object sender, SelectionChangedEventArgs e)
        {
            if (sketchSheets == null)
                return;

            var tab = (TabItem)sketchSheets.SelectedItem;
            var inkCanvas = (InkCanvas)tab.Content;

            var comboBox = (ComboBox)sender;
            var element = (FrameworkElement)comboBox.SelectedItem;
            var tag = (string)element.Tag;

            var editingMode = (InkCanvasEditingMode)Enum.Parse(typeof(InkCanvasEditingMode), tag);
            inkCanvas.EditingMode = editingMode;
        }

        private void OnBrushFormChanged(object sender, SelectionChangedEventArgs e)
        {
            if (sketchSheets == null)
                return;

            var tab = (TabItem)sketchSheets.SelectedItem;
            var inkCanvas = (InkCanvas)tab.Content;

            var comboBox = (ComboBox)sender;
            var element = (FrameworkElement)comboBox.SelectedItem;
            var stylusTip = (StylusTip)element.Tag;

            inkCanvas.DefaultDrawingAttributes.StylusTip = stylusTip;
        }

        private void OnBrushColorChanged(object sender, SelectionChangedEventArgs e)
        {
            var tab = (TabItem)sketchSheets.SelectedItem;
            var inkCanvas = (InkCanvas)tab.Content;

            var propertyInfo = (PropertyInfo)colorList.SelectedItem;
            var color = (Color)propertyInfo.GetValue(null, null);

            inkCanvas.DefaultDrawingAttributes.Color = color;

            expanderColumns.IsExpanded = false;
        }
        private void OnBrushSizeChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            var tab = (TabItem)sketchSheets.SelectedItem;
            var inkCanvas = (InkCanvas)tab.Content;

            var size = brushSlider.Value;

            inkCanvas.DefaultDrawingAttributes.Width = size;
            inkCanvas.DefaultDrawingAttributes.Height = size;
        }

        private void OnLineShapeChanged(object sender, SelectionChangedEventArgs e)
        {

        }

        private void OnEditMenuOpened(object sender, RoutedEventArgs e)
        {
            var tab = (TabItem)sketchSheets.SelectedItem;
            var inkCanvas = (InkCanvas)tab.Content;

            menuCopy.IsEnabled = inkCanvas.GetSelectedStrokes().Count > 0;
            menuCut.IsEnabled = inkCanvas.GetSelectedStrokes().Count > 0;
            menuPaste.IsEnabled = inkCanvas.CanPaste();
        }

        private void OnCut(object sender, RoutedEventArgs e)
        {
            var tab = (TabItem)sketchSheets.SelectedItem;
            var inkCanvas = (InkCanvas)tab.Content;

            inkCanvas.CutSelection();
        }

        private void OnCopy(object sender, RoutedEventArgs e)
        {
            var tab = (TabItem)sketchSheets.SelectedItem;
            var inkCanvas = (InkCanvas)tab.Content;

            inkCanvas.CopySelection();
        }

        private void OnPaste(object sender, RoutedEventArgs e)
        {
            var tab = (TabItem)sketchSheets.SelectedItem;
            var inkCanvas = (InkCanvas)tab.Content;

            inkCanvas.Paste();
        }
    }

}
