﻿using System;
using System.Collections.ObjectModel;
using System.IO;
using System.Linq;
using System.Windows.Media.Imaging;

namespace Navigation_5
{
    public class Picture
    {
        public string Name { get; set; }
        public BitmapImage BitmapImage { get; set; }
        public DateTime DateCreated { get; set; }
        public string Path { get; set; }
        public string FileType { get; set; }
    }

    public class PictureList : ObservableCollection<Picture>
    {
        public PictureList(string pathDirectory)
        {
            Refresh(pathDirectory);
        }

        private void Refresh(string pathDirectory)
        {
            string[] directories = Directory.GetDirectories(pathDirectory);

            var uri = new Uri("/Assets/Directory.png", UriKind.Relative);

            foreach (string directory in directories)
            {
                this.Add(new Picture()
                {
                    BitmapImage = new BitmapImage(uri),
                    Name = directory.Substring(directory.LastIndexOf('\\') + 1),
                    Path = directory
                });
            }

            string[] fileNames = Directory.GetFiles(pathDirectory, "*.png")
                                                        .Union(Directory.GetFiles(pathDirectory, "*.jpg"))
                                                        .Union(Directory.GetFiles(pathDirectory, "*.jpeg"))
                                                        .OrderBy(f => f)
                                                        .ToArray();

            foreach (string fileName in fileNames)
            {
                BitmapImage bitmap = new BitmapImage();

                bitmap.BeginInit();
                bitmap.UriSource = new Uri(fileName);
                bitmap.DecodePixelWidth = 150;
                bitmap.EndInit();

                this.Add(new Picture()
                {
                    Name = Path.GetFileNameWithoutExtension(fileName),
                    BitmapImage = bitmap,
                    DateCreated = File.GetCreationTime(fileName),
                    Path = fileName,
                    FileType = Path.GetExtension(fileName)
                });
            }
        }
    }
}
