﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Reflection;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;

namespace SimpleControls_7
{
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            IEnumerable<PropertyInfo> list = typeof(Typography).GetTypeInfo().DeclaredProperties;

            foreach (PropertyInfo prop in list)
            {
                var item = new ComboBoxItem();
                item.Content = prop.Name.Replace("Property", "");
                typo.Items.Add(item);
            }
            typo.SelectedIndex = 0;
        }

        private class Method
        {
            public MethodInfo MethodInfo { get; set; }
            public Type[] ParameterTypes { get; set; }
        }

        private void OnTypoSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            var item = (ComboBoxItem)typo.SelectedValue;

            Method method;

            if (item.Tag == null)
            {
                var property = item.Content;

                IEnumerable<MethodInfo> list =
                   typeof(Typography).GetRuntimeMethods()
                                     .Where(m => m.Name == "Set" + property);

                MethodInfo methodInfo = list.First<MethodInfo>();

                method = new Method();
                method.MethodInfo = methodInfo;

                item.Tag = method;
            }
            else
                method = (Method)item.Tag;

            param.Items.Clear();

            ParameterInfo[] pars = method.MethodInfo.GetParameters();
            Type[] types = new Type[2];

            types[0] = pars[0].ParameterType;
            types[1] = pars[1].ParameterType;

            method.ParameterTypes = types;

            if (types[1] == typeof(bool))
            {
                param.Items.Add(bool.TrueString);
                param.Items.Add(bool.FalseString);
            }
            else if (types[1] == typeof(int))
            {
                param.Items.Add(0);
                param.Items.Add(1);
                param.Items.Add(2);
                param.Items.Add(3);
            }
            else
            {
                string[] enums = Enum.GetNames(types[1]);

                foreach (string name in enums)
                    param.Items.Add(name);
            }

            param.SelectedIndex = 0;
        }

        private void OnParamSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (param.SelectedIndex == -1)
                return;

            var item = (ComboBoxItem)typo.SelectedItem;
            var method = (Method)item.Tag;

            object value = param.SelectedItem.ToString();

            if (method.ParameterTypes[1] == typeof(bool))
            {
                value = (bool)bool.Parse((string)value);
            }
            else if (method.ParameterTypes[1] == typeof(int))
            {
                value = (int)int.Parse((string)value);
            }
            else
            {
                value = Enum.Parse(method.ParameterTypes[1], (string)value);
            }

            Run run = new Run();
            run.Text = input.Text;

            method.MethodInfo.Invoke(run, new object[] { run, value });

            text.Inlines.Clear();
            text.Inlines.Add(run);
        }
    }
}
